Review Request: JDK-8171201 & JDK-8171202: Drop java.compact$N aggregator modules

Mandy Chung mandy.chung at oracle.com
Wed Dec 14 16:19:05 UTC 2016


> On Dec 14, 2016, at 12:03 AM, Alan Bateman <Alan.Bateman at oracle.com> wrote:
> 
> On 14/12/2016 06:49, Mandy Chung wrote:
> 
>> JDK-8171201: Drop java.compact$N aggregator modules
>> JDK-8171202: Rename jdk.crypto.pkcs11 and jdk.pack200 to end with Java letters
>> 
>> http://cr.openjdk.java.net/~mchung/jdk9/webrevs/8171201%2b8171202/webrev.00/
>> 
>> 
> The hg moves are showing up as new files in the webrev - is that because the webrev is on several repos?
> 

Not sure and it might be webrev on several repos.

The number of lines changed is zero which is correct.

> In the LimitModsTest test then it might be simpler to leave java.scripting out of the test.

Sure.

$ hg diff limitmods/LimitModsTest.java
diff --git a/test/tools/launcher/modules/limitmods/LimitModsTest.java b/test/tools/launcher/modules/limitmods/LimitModsTest.java
--- a/test/tools/launcher/modules/limitmods/LimitModsTest.java
+++ b/test/tools/launcher/modules/limitmods/LimitModsTest.java
@@ -24,7 +24,7 @@
 /**
  * @test
  * @library /lib/testlibrary
  * @modules java.desktop java.compact1 jdk.compiler
  * @build LimitModsTest CompilerUtils jdk.testlibrary.*
  * @run testng LimitModsTest
  * @summary Basic tests for java --limit-modules
@@ -83,13 +83,12 @@
         assertTrue(exitValue == 0);
 
 
-        // java --limit-modules java.compact1 --list-modules
-        exitValue = executeTestJava("--limit-modules", "java.compact1", "--list-modules")
+        // java --limit-modules java.logging --list-modules
+        exitValue = executeTestJava("--limit-modules", "java.logging", "--list-modules")
             .outputTo(System.out)
             .errorTo(System.out)
             .shouldContain("java.base")
             .shouldContain("java.logging")
-            .shouldContain("java.compact1")
             .shouldNotContain("java.xml")
             .getExitValue();
 
@@ -24,7 +24,7 @@
  * @test
  * @library /lib/testlibrary
- * @modules java.desktop java.compact1 jdk.compiler
+ * @modules java.desktop java.logging jdk.compiler
  * @build LimitModsTest CompilerUtils jdk.testlibrary.*
  * @run testng LimitModsTest

> Also in the java.se aggregator then it looks like the module comment has a line break after "The module defining" and can probably be fixed as part of this edit.
> 

Fixed.

/**
 * Defines the core Java SE API.
 * <P>
 * The modules defining CORBA and Java EE APIs are not required by
 * this module, but they are required by {@code java.se.ee}.
 */

Mandy



More information about the jigsaw-dev mailing list